==> 0.5.0.tar.gz: lib/fc_cell.dart <==
import 'dart:async';

import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class FcCell extends StatefulWidget {
  const FcCell({
    Key? key,
    this.onPressed,
    this.crossAxisAlignment = CrossAxisAlignment.center,
    required this.label,
    this.content,
    this.contentAlignment = Alignment.centerRight,
    this.arrow = true,
    this.border = true,
  }) : super(key: key);

  /// 点击事件回调
  ///
  /// 当 [onPressed] 不为null时将点击态将变得有效
  final VoidCallback? onPressed;

  /// 交叉轴对齐方式
  ///
  /// 默认为 [CrossAxisAlignment.center] 垂直居中
  final CrossAxisAlignment crossAxisAlignment;

  /// 标题，必传
  final Widget label;

  /// 内容
  final Widget? content;

  /// 内容对齐方式
  ///
  /// 默认 [Alignment.centerRight] 居中右对齐
  final Alignment contentAlignment;

  /// 是否显示右侧箭头
  ///
  /// 默认为 [true] 显示
  final bool arrow;

  /// 是否显示边框
  ///
  /// 默认为 [false] 不显示
  final bool border;

  @override
  _FcCellState createState() => _FcCellState();
}

class _FcCellState extends State<FcCell> {
  bool onPress = false;

  /// 底部边框
  BoxBorder? get bottomBorder {
    if (widget.border) {
      return Border(bottom: BorderSide(color: Colors.black.withOpacity(0.1)));
    }
    return null;
  }

  /// 内容
  Widget get content {
    if (widget.content != null) {
      return Container(
        alignment: widget.contentAlignment,
        padding: EdgeInsets.symmetric(horizontal: Adapt.px(20)),
        child: DefaultTextStyle(
          style: TextStyle(
            color: const Color(0xFFAFAFB3),
            fontSize: Adapt.px(31),
            fontWeight: FontWeight.w500,
            height: 1.4,
          ),
          child: widget.content!,
        ),
      );
    }

    return Container();
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> rowList = [
      DefaultTextStyle(
        style: TextStyle(
          color: const Color(0xFF323233),
          fontSize: Adapt.px(31),
          fontWeight: FontWeight.w500,
          height: 1.4,
        ),
        child: widget.label,
      ),
      Expanded(child: content),
    ];

    if (widget.arrow) {
      rowList.add(Icon(
        Icons.keyboard_arrow_right_rounded,
        color: Colors.black.withOpacity(0.3),
        size: Adapt.px(50),
      ));
    }

    return InkWell(
      onTap: widget.onPressed,
      onHighlightChanged: (bool value) {
        if (onPress != value) {
          if (value) {
            setState(() {
              onPress = value;
            });
          } else {
            Timer(const Duration(milliseconds: 100), () {
              setState(() {
                onPress = value;
              });
            });
          }
        }
      },
      child: Stack(
        children: [
          Container(
            padding: EdgeInsets.only(left: Adapt.px(33)),
            decoration: const BoxDecoration(color: Colors.white),
            constraints: BoxConstraints(
              minWidth: Adapt.screenW(),
              minHeight: Adapt.px(100),
            ),
            child: Container(
              padding: EdgeInsets.only(
                right: Adapt.px(10),
                top: Adapt.px(28),
                bottom: Adapt.px(28),
              ),
              decoration: BoxDecoration(
                border: bottomBorder,
              ),
              child: Row(
                crossAxisAlignment: widget.crossAxisAlignment,
                children: rowList,
              ),
            ),
          ),
          Positioned(
            top: 0,
            bottom: 0,
            left: 0,
            width: onPress ? Adapt.screenW() : 0,
            child: Container(
              width: Adapt.screenW(),
              height: Adapt.px(100),
              decoration: BoxDecoration(color: Colors.black.withOpacity(0.1)),
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.5.7.tar.gz: lib/fc_cell.dart <==
import 'dart:async';

import 'package:fc_components/util/adapt.dart';
import 'package:flutter/material.dart';

class FcCell extends StatefulWidget {
  const FcCell({
    Key? key,
    this.onPressed,
    this.crossAxisAlignment = CrossAxisAlignment.start,
    required this.label,
    this.content,
    this.contentAlignment = Alignment.centerRight,
    this.arrow = true,
    this.extra,
    this.border = true,
  }) : super(key: key);

  /// 点击事件回调
  ///
  /// 当 [onPressed] 不为null时将点击态将变得有效
  final VoidCallback? onPressed;

  /// 交叉轴对齐方式
  ///
  /// 默认为 [CrossAxisAlignment.center] 垂直居中
  final CrossAxisAlignment crossAxisAlignment;

  /// 标题，必传
  final Widget label;

  /// 内容
  final Widget? content;

  /// 内容对齐方式
  ///
  /// 默认 [Alignment.centerRight] 居中右对齐
  final Alignment contentAlignment;

  /// 是否显示右侧箭头
  ///
  /// 默认为 [true] 显示
  final bool arrow;

  /// 最右侧扩展内容
  ///
  /// 默认无
  final Widget? extra;

  /// 是否显示边框
  ///
  /// 默认为 [false] 不显示
  final bool border;

  @override
  _FcCellState createState() => _FcCellState();
}

class _FcCellState extends State<FcCell> {
  bool onPress = false;

  /// 底部边框
  BoxBorder? get bottomBorder {
    if (widget.border) {
      return Border(bottom: BorderSide(color: Colors.black.withOpacity(0.1)));
    }
    return null;
  }

  /// 内容
  Widget get content {
    if (widget.content != null) {
      return Container(
        alignment: widget.contentAlignment,
        padding: EdgeInsets.symmetric(horizontal: Adapt.px(20)),
        child: DefaultTextStyle(
          style: TextStyle(
            color: const Color(0xFF999999),
            fontSize: Adapt.px(28),
            fontWeight: FontWeight.w500,
            height: 1.5,
          ),
          child: widget.content!,
        ),
      );
    }

    return Container();
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> rowList = [
      DefaultTextStyle(
        style: TextStyle(
          color: const Color(0xFF323233),
          fontSize: Adapt.px(28),
          fontWeight: FontWeight.w500,
          height: 1.5,
        ),
        child: widget.label,
      ),
      Expanded(child: content),
    ];

    /// 右侧箭头
    if (widget.arrow) {
      rowList.add(Icon(
        Icons.keyboard_arrow_right_rounded,
        color: Colors.black.withOpacity(0.3),
        size: Adapt.px(50),
      ));
    }

    /// 最右侧扩展内容
    if (widget.extra != null) {
      rowList.add(DefaultTextStyle(
        style: TextStyle(
          fontSize: Adapt.px(28),
          fontWeight: FontWeight.w400,
          height: 1.5,
        ),
        child: widget.extra!,
      ));
    }

    return InkWell(
      onTap: widget.onPressed,
      onHighlightChanged: (bool value) {
        if (onPress != value) {
          if (value) {
            setState(() {
              onPress = value;
            });
          } else {
            Timer(const Duration(milliseconds: 100), () {
              setState(() {
                onPress = value;
              });
            });
          }
        }
      },
      child: Stack(
        children: [
          Container(
            padding: EdgeInsets.all(Adapt.px(32)),
            decoration: BoxDecoration(
              color: Colors.white,
              border: bottomBorder,
            ),
            child: Row(
              crossAxisAlignment: widget.crossAxisAlignment,
              children: rowList,
            ),
          ),
          Positioned(
            top: 0,
            bottom: 0,
            left: 0,
            width: onPress ? Adapt.screenW() : 0,
            child: Container(
              width: Adapt.screenW(),
              height: Adapt.px(100),
              decoration: BoxDecoration(color: Colors.black.withOpacity(0.1)),
            ),
          ),
        ],
      ),
    );
  }
}
